@@ -224,7 +224,7 @@ void DebuggerMainWnd::initKAction()
     for (unsigned i = 0; i < sizeof(dw)/sizeof(dw[0]); i++) {
 	KDockWidget* d = dockParent(dw[i].w);
 	(void)new TDEToggleAction(dw[i].text, 0, d, SLOT(changeHideShowState()),
-			  actionCollection(), dw[i].id);
+			  actionCollection(), dw[i].id.latin1());
     }
 
     
@@ -485,7 +485,7 @@ void DebuggerMainWnd::updateUI()
 void DebuggerMainWnd::dockUpdateHelper(TQString action, TQWidget* w)
 {
     TDEToggleAction* item =
-	static_cast<TDEToggleAction*>(actionCollection()->action(action));
+	static_cast<TDEToggleAction*>(actionCollection()->action(action.latin1()));
     bool canChange = canChangeDockVisibility(w);
     item->setEnabled(canChange);
     item->setChecked(canChange && isDockVisible(w));
