@@ -25,7 +25,7 @@ class TQPopupMenu;
  */
 class STTY : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public: 
     STTY();
     ~STTY();
@@ -48,7 +48,7 @@ protected:
 
 class TTYWindow : public TQTextEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     TTYWindow(TQWidget* parent, const char* name);
     ~TTYWindow();
